<?php
  session_start();

/*

PBSWeb -- A Web-based Interface to PBS
Copyright (C) 2000, 2001  Paul Lu

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

------
Please leave this copyright notice intact.
See http://www.gnu.org/copyleft/gpl.html for further details

Contact information:
	Paul Lu
	Assistant Professor
	Dept. of Computing Science
	Athabasca Hall
	University of Alberta
	Edmonton, Alberta, T6G 2E8
	Canada

	E-mail:         paullu@cs.ualberta.ca
	Web:            http://www.cs.ualberta.ca/~paullu/

Other contributors to PBSWeb (as of July 2001)
	George Ma, Victor Salamon, Christopher Pinchak, Yaling Pei,
	Jonathan Schaeffer, Duane Szafron
*/

/* WARNING: This script is difficult to understand.  This is because
   this same script must do three things:

   1. Present a page where the user selects a previously-submitted job.
      This corresponds to $orders = ""

   2. Present a page where the user creates a new job.
	  This corresponds to $orders = "newjob"

   3. Perform the submission of the job to PBS and display the associated
      information.
      This corresponds to $orders = "submitjob"

   This process is made even more complicated by the client-side JavaScript
   that is present within the page.
*/
  session_register('username');
  session_register('sessionkey');

  include_once("utils.php");
  include_once("dbutils.php");
  include_once("PBSWebConstants.php");
  DB_authPage($sessionkey);

  $local_debug = 0;
?>

<?php
  // hostname is $host , programname is $program, orders is $orders 
  if(""==$host)
  { dispErrorPageAutoHelp("No host defined. Please go back and select a host."); die; }

  if(""==$program)
  { dispErrorPageAutoHelp("No program name defined. Please go back and select a program name."); die; }

  # Vick 20010221 allow determining all queues except when submitting job 
  if('submitjob'!=$orders)
  {
     // Chris 20010601: Modified qstat_str to get qstat from the database.
     $qstat_cmd = DB_getHostInfo($host, "qstat");
     if ($qstat_cmd == PBSFALSERET) {
        dispErrorPageAutoHelp("Error fetching qstat command. Database may be down");
	die;
     }
     $qstat_str="ssh -q -l $username $host '$qstat_cmd -Qf|grep Queue:' 2>&1";
     pbsdbg(__FILE__, __LINE__,"executing $qstat_str");

     unset($qarray_computed_above);
     exec($qstat_str, $qarray_computed_above, $return_val);
     if($return_val)
     { 
       dispErrorPageAutoHelp("last command returned $return_val<br>\n
                      The output: ".array_to_str($qarray_computed_above)); 
       die; 
     }

     # get rid of "stty: standard input: Invalid argument"
     $qarray_computed_above = filterArray($qarray_computed_above, 
                                          "stty: standard input: Invalid argument", 
                                          0);
     # Get rid of "Queue:" prefix
     for($i=0;$i<count($qarray_computed_above);$i++)
     { $qarray_computed_above[$i]=str_replace("Queue:","",$qarray_computed_above[$i]); }
  }

  if('submitjob'==$orders) 
  {
# Paul moved this here from below
    $submitted_job_str="<h2>Script Submission Results</h2>";

    $program_path=DB_getProgramPath($username,$host,$program);

    if(PBSFALSERET==$program_path)
    { dispErrorPageAutoHelp($PBSWebErrMsg); die; }

    pbsdbg(__FILE__, __LINE__,"Got program_path:$program_path");
    pbsdbg(__FILE__, __LINE__,"Got queue:$queue");
    pbsdbg(__FILE__, __LINE__,"Got ncpus:$ncpus");
    pbsdbg(__FILE__, __LINE__,"Got jobselect:$jobselect");
    pbsdbg(__FILE__, __LINE__,"Got jobname:$jobname");
    pbsdbg(__FILE__, __LINE__,"Got orders:$orders");

    pbsdbg(__FILE__, __LINE__,"Generating pbsweb script:");
    $pbsweb_script_str="#This script file was automatically generated by PBSWeb\n";
    // Chris 20010601: This will have to be obtained from the database in the
    // future.
    $pbsweb_script_str.="#!/bin/sh\n";
    $pbsweb_script_str.="#PBS -S /bin/sh\n";

    if($jobname != "") 
    { $pbsweb_script_str.="#PBS -N $jobname\n"; }

# Paul/George:  Added this get rid of leading space, which might be from Javascript
# $queue=trim($queue);

    if(($queue != "" )&&($queue != "dque")) 
    { $pbsweb_script_str.="#PBS -q $queue\n"; }

    // Chris 20010601: Because maci-cluster does not use processors, but rather
    // uses nodes, requesting a different number of processors requires a
    // different command.
    if($ncpus !="") { 
      if ($host == "maci-cluster.ucalgary.ca")
        $pbsweb_script_str .= "#PBS -W vnodes=$ncpus\n";
      else
        $pbsweb_script_str.="#PBS -l ncpus=$ncpus\n";
    }

    if(($maxtime !="") && ($maxtime != "00:00:00")) 
    { $pbsweb_script_str.="#PBS -l walltime=$maxtime\n"; }

    if($join == "1") 
    { $pbsweb_script_str.="#PBS -j oe\n"; }

    if($address) 
    {
       $pbsweb_script_str.="#PBS -M $address\n";

       if($mailabort)
       { $mopts.='a'; }
       if($mailend)
       { $mopts.='e'; }
       if($mailbegin)
       { $mopts.='b'; }
       
       if ($mopts!="") 
       { $pbsweb_script_str.="#PBS -m $mopts\n"; }
    }
    else 
    { $pbsweb_script_str.="#PBS -m n\n"; }

    // Chris 20010601: This mess will probably disappear now that borealis
    // no longer required stage-in.    
	# Mess removed by Paul

    if($host=="maci-cluster.ucalgary.ca")
    {
      // Chris 20010601: Removed ~ from the path because Calgary doesn't like
      // it.
      //$pbsweb_script_str.="cd ~/$PBSWEBDIR/$program\n";
      $pbsweb_script_str.="cd $PBSWEBDIR/$program\n";
    }
    else
    if( ($host=="aurora.nic.ualberta.ca")&&($queue==" borealis") )
    {
      $pbsweb_script_str.="cd /scratch/$username/pbsweb/$program\n";
    }
    else
    {
      $pbsweb_script_str.="cd ~/$PBSWEBDIR/$program\n";
    }
    
    # Vick 20010220 PROGRAM_PATH_OUT
    # $pbsweb_script_str.="cd $program_path\n";

    $commands=str_replace("\x0d","",$commands);
# Paul/Victor April 20/01
# Replace ;; from database version for usage version
    $commands=str_replace(";;","\n",$commands);

    $pbsweb_script_str.=$commands;

    pbsdbg(__FILE__, __LINE__,"Generated contents: $$pbsweb_script_str");

    $datestring = date("ymd_H_i");
    $script_filename = "$program".".$datestring".".pbs";
    $file_to_open = "$TEMPUPLOADDIR/$username/$script_filename";

    pbsdbg(__FILE__, __LINE__,"Opening file $file_to_open");

    $fp = fopen($file_to_open,"w");
    if(!$fp)
    { dispErrorPageAutoHelp("Can't open $script_filename for write"); die; }

    if(-1==fwrite($fp, $pbsweb_script_str))
    { dispErrorPageAutoHelp("Can't write to $script_filename"); die; }

    fclose($fp);

    # Vick 20010220 PROGRAM_PATH_OUT
    # $scpscript_str="scp -q $TEMPUPLOADDIR/$username/$script_filename $username@$host:~/$PBSWEBDIR/$program/$program_path 2>&1";
    $scpscript_str="/usr/bin/scp -q $TEMPUPLOADDIR/$username/$script_filename $username@$host:~/$PBSWEBDIR/$program/ 2>&1";
    
    pbsdbg(__FILE__, __LINE__,"executing $scpscript_str");
    # Vick 20010214 replaced $scpscript = `$scpscript_str`;
    unset($tmp_array);
    exec($scpscript_str, $tmp_array, $return_val);
    if($return_val)
    { dispErrorPageAutoHelp("last command returned $return_val<br>\nThe output: $tmp_array"); die; }
    
    // Chris 20010601: Modified qsub_str to get qsub from the database.
    //$qsub_str = "ssh -l $username $host 'cd $PBSWEBDIR/$program/; qsub $script_filename' 2>&1";
    $qsub_cmd = DB_getHostInfo($host, "qsub");
    if ($qsub_cmd == PBSFALSERET) {
      dispErrorPageAutoHelp("Error fetching qsub command. Database may be down");
      die();
    }
    $qsub_str = "ssh -l $username $host 'cd $PBSWEBDIR/$program/; $qsub_cmd $script_filename' 2>&1";
    pbsdbg(__FILE__, __LINE__,"executing $qsub_str");
    unset($tmp_array);
    exec($qsub_str, $tmp_array, $return_val);

    if( $local_debug == 1 )
    {
# Paul.  Temp.
	$submitted_job_str.="\n<p><b>Paul Debug: PBS qsub command:</b>  $qsub_str</p>";
# Known problem not fixed:  $tmp_array is an array and one has to either
#	print each index invidually, or concatenate them all first.
#	Look for built-in PHP function later.
	$submitted_job_str.="\n<p><b>Paul Debug: PBS qsub returns (1):</b>  $tmp_array</p>";
	$submitted_job_str.="\n<p><b>Paul Debug: PBS qsub returns (2):</b>  $return_val</p>";
    }

    if($return_val)
    { dispErrorPageAutoHelp("last command returned $return_val<br>\nThe output: $tmp_array"); die; }

    pbsdbg(__FILE__, __LINE__,"The output of last command is:");
    $pbsjobid="";
    for($i=0;$i<count($tmp_array[$i]);$i++)
    {
      pbsdbg(__FILE__, __LINE__,"$tmp_array[$i]");
      if(""==$pbsjobid)
      { 
        $tmp_array2=explode(".",$tmp_array[$i]);
	list($pbsjobid)=sscanf($tmp_array2[0],"%d");
      }
    }

    $jobinfo["jobname"]=$jobname;
    $jobinfo["jobscript"]=$commands;
    $jobinfo["queue"]=$queue;
    $jobinfo["ncpus"]=$ncpus;
    $jobinfo["maxtime"]=$maxtime;
    $jobinfo["merge"]=$join;
    $jobinfo["in_here"]=$stageinhere;
    $jobinfo["in_there"]=$stageinthere;
    $jobinfo["out_here"]=$stageouthere;
    $jobinfo["out_there"]=$stageoutthere;
    $jobinfo["mail_start"]=$mailbegin;
    $jobinfo["mail_end"]=$mailend;
    $jobinfo["mail_abort"]=$mailabort;
    $jobinfo["mailaddress"]=$address;
    $jobinfo["deleted"]='0';

    $dbsubjob = DB_submit_job($username,$sessionkey,$program,$host,$pbsjobid,$jobinfo);
    if(PBSFALSERET==$dbsubjob)
    { dispErrorPageAutoHelp($PBSWebErrMsg); die; }

    $submitted_job_str.="<p><b>Job Name:</b> $jobname</p>";

    $submitted_job_str.="\n<p><b>Script Filename:</b>$script_filename</p>";
    $submitted_job_str.="\n<p><b>Script File Contents:</b></p><pre>$pbsweb_script_str</pre>";
    $submitted_job_str.="\n<p><b>PBS Job ID:</b>  $pbsjobid</p>";




# Paul:  Added code to copy Here
    $copy_str = "ssh -l $username $host 'cd $PBSWEBDIR/$program/; cp $script_filename $script_filename.$pbsjobid' 2>&1";
    pbsdbg(__FILE__, __LINE__,"executing $copy_str");
    unset($tmp_array);
    exec($copy_str, $tmp_array, $return_val);
    if($return_val)
    { dispErrorPageAutoHelp("last command returned $return_val<br>\nThe output: $tmp_array"); die; }
    $submitted_job_str.="\n<p><b>A copy of the script is saved in:</b>  $script_filename.$pbsjobid</p>";



    $submitted_job_str.="\nSuggested Next Step:  <a href=qstat.php?host=$host>View Queue Status</a>";

    $submitted=TRUE;

  }
  else
  if('newjob'!=$orders)
  {

      $jobnames_list=DB_get_job_list($username, $program, $host);
      if(PBSFALSERET==$jobnames_list)
      { dispErrorPageAutoHelp($PBSWebErrMsg); die; }

      $javascript_str="\n\t// defining CJob class";
      $javascript_str.="\n\t  // attention! you can't use the word 'delete' -> it's reserved";
      $javascript_str.="\n\tfunction CJob(jobname,jobscript,script_id,queue,ncpus,maxtime,merge,
                                         in_here, in_there, out_here, out_there,
       		                         mail_abort, mail_start, mail_end, mailaddress, delete_d)
                       {
                        this.jobname    = jobname;
                        this.jobscript  = jobscript;
			this.script_id  = script_id;
			this.queue      = queue;
			this.ncpus      = ncpus;
			this.maxtime    = maxtime;

                        // Vick 20010221 another way of handling null checkbox.checked values
                        if(isNaN(parseInt(merge)))
			{ merge=0; }
			this.merge    = merge;

                        this.in_here    = in_here;
			this.in_there   = in_there;
			this.out_here   = out_here;
			this.out_there  = out_there;
			
			if(isNaN(parseInt(mail_abort)))
			{ mail_abort=0; }
			this.mail_abort = mail_abort;

			if(isNaN(parseInt(mail_start)))
			{ mail_start=0; }
			this.mail_start = mail_start;

			if(isNaN(parseInt(mail_end)))
			{ mail_end=0; }
			this.mail_end   = mail_end;

                        this.mailaddress=mailaddress; 
		        this.delete_d   = delete_d;
		       }
                       var jobs=new Array(".count($jobnames_list).");";
      for($i=0;$i<count($jobnames_list);$i++)
      {
        $job=DB_get_job($username, $program, $host, $jobnames_list[$i]);

	# for now, replace newlines with semicolons
        $job["jobscript"]=str_replace("\n",";",$job["jobscript"]);

        if(PBSFALSERET==$job)
        { dispErrorPageAutoHelp($PBSWebErrMsg); die; }

        $javascript_str.="\n\tjobs[$i]=new CJob(".
                                              "'".$jobnames_list[$i]."',".
                                              "'".$job["jobscript"]."',".
                                              "'".$job["script_id"]."',".
                                              "'".$job["queue"]."',".
                                              "'".$job["ncpus"]."',".
                                              "'".$job["maxtime"]."',".
                                              "'".$job["merge"]."',".
                                              "'".$job["in_here"]."',".
                                              "'".$job["in_there"]."',".
                                              "'".$job["out_here"]."',".
                                              "'".$job["out_there"]."',".
                                              "'".$job["mail_abort"]."',".
                                              "'".$job["mail_start"]."',".
                                              "'".$job["mail_end"]."',".
                                              "'".$job["mailaddress"]."',".
                                              "'".$job["delete"]."'".
                     ");";

      }
      $javascript_str.="\n\n";

      $javascript_str.=get_javascript_select_function();

      $javascript_str.="\n\n";

      $javascript_str.="\n\tfunction populateProperties()
                            {
    		              var selected=window.document.forms[0].jobselect.selectedIndex;
			      if(-1!=selected)
			      {
		                var jobname =window.document.forms[0].jobselect.options[selected].value;

  			        window.document.forms[0].commands.value=jobs[selected].jobscript;

  			        // window.document.forms[0].queue.value=jobs[selected].queue;
  			        // window.document.forms[0].queue.options[0]=new Option();
			        // window.document.forms[0].queue.options[0].value=jobs[selected].queue;
				// if(''==jobs[selected].queue)
				// { window.document.forms[0].queue.options[0].text='Default'; }
				// else
				// { window.document.forms[0].queue.options[0].text=jobs[selected].queue; }
				utils_select_option(window.document.forms[0].queue,jobs[selected].queue);

  			        // window.document.forms[0].ncpus.options[0]=new Option();
			        // window.document.forms[0].ncpus.options[0].value=jobs[selected].ncpus;
			        // window.document.forms[0].ncpus.options[0].text=jobs[selected].ncpus;
				utils_select_option(window.document.forms[0].ncpus,jobs[selected].ncpus);

  			        window.document.forms[0].maxtime.value=jobs[selected].maxtime;

  			        window.document.forms[0].join.checked=jobs[selected].merge;
  			        window.document.forms[0].mailabort.checked=jobs[selected].mail_abort;
  			        window.document.forms[0].mailbegin.checked=jobs[selected].mail_start;
  			        window.document.forms[0].mailend.checked=jobs[selected].mail_end;

  			        window.document.forms[0].address.value=jobs[selected].mailaddress;

  			        window.document.forms[0].stageinhere.value=jobs[selected].in_here;
  			        window.document.forms[0].stageinthere.value=jobs[selected].in_there;
  			        window.document.forms[0].stageouthere.value=jobs[selected].out_here;
  			        window.document.forms[0].stageoutthere.value=jobs[selected].out_there;
                              }
			      else
			      {
			        // clear all
  			        window.document.forms[0].commands.value='';

  			        // window.document.forms[0].queue.options[0]=new Option();
			        window.document.forms[0].queue.options[0].value='Default';
			        window.document.forms[0].queue.options[0].text='Default';

  			        // window.document.forms[0].ncpus.options[0]=new Option();
			        window.document.forms[0].ncpus.options[0].value='Default';
			        window.document.forms[0].ncpus.options[0].text='Default';

  			        window.document.forms[0].maxtime.value='00:00:00';

  			        window.document.forms[0].join.checked=0;
  			        window.document.forms[0].mailabort.checked=0;
  			        window.document.forms[0].mailbegin.checked=0;
  			        window.document.forms[0].mailend.checked=0;

  			        window.document.forms[0].address.value='';

  			        window.document.forms[0].stageinhere.value='';
  			        window.document.forms[0].stageinthere.value='';
  			        window.document.forms[0].stageouthere.value='';
  			        window.document.forms[0].stageoutthere.value='';
			      }
		        }";
   }
   else
   {
      $dbaddress = DB_getUserEmail($username);
      if(PBSFALSERET==$dbaddress)
      { dispErrorPageAutoHelp($PBSWebErrMsg); die; }
   }

   $javascript_str.="
                        function clearFileStaging()
			{
			   window.document.forms[0].stageinhere.value='';
			   window.document.forms[0].stageinthere.value='';
			   window.document.forms[0].stageouthere.value='';
			   window.document.forms[0].stageoutthere.value='';
			}
                    ";

   if('newjob'!=$orders)
   {
      $javascript_str.="
			function checkSubmit()
			{
		          var selected=window.document.forms[0].jobselect.selectedIndex;
                          var changes_txt='';
			  var tmp_idx;
			  var new_jobname='';

			  if(-1==selected)
			  { 
			    new_jobname=prompt('No job selected ! Please select a job or enter new job name','New-job'); 

			    if(null==new_jobname)
  			    { return; }

			    if(''==new_jobname)
			    { alert('Empty job name'); return; }

			    window.document.forms[0].jobname.value=new_jobname;
			    window.document.forms[0].orders.value='submitjob';
			    window.document.forms[0].submit(); 
			  }
			  else
                          { 
			    if(window.document.forms[0].commands.value!=jobs[selected].jobscript)
			    { changes_txt+='execution commands,'; }

                            tmp_idx=window.document.forms[0].queue.selectedIndex; 
  			    if(window.document.forms[0].queue.options[tmp_idx].value!=jobs[selected].queue)
			    { changes_txt+='queue,'; }
			 
                            tmp_idx=window.document.forms[0].ncpus.selectedIndex; 
			    if(window.document.forms[0].ncpus.options[tmp_idx].value!=jobs[selected].ncpus)
			    { changes_txt+='number of CPUs,'; }

 			    if(window.document.forms[0].maxtime.value!=jobs[selected].maxtime)
			    { changes_txt+='maxtime,'; }

  			    if(window.document.forms[0].join.checked!=jobs[selected].merge)
			    { changes_txt+='output merge,'; }

  			    if(window.document.forms[0].mailabort.checked!=jobs[selected].mail_abort)
			    { changes_txt+='mail at abort,'; }

 			    if(window.document.forms[0].mailbegin.checked!=jobs[selected].mail_start)
			    { changes_txt+='mail at begin,'; }

  			    if(window.document.forms[0].mailend.checked!=jobs[selected].mail_end)
			    { changes_txt+='mail at end,'; }

  			    if(window.document.forms[0].address.value!=jobs[selected].mailaddress)
			    { changes_txt+='email address,'; }

  			    if(window.document.forms[0].stageinhere.value!=jobs[selected].in_here)
			    { changes_txt+='stage in here,'; }

  			    if(window.document.forms[0].stageinthere.value!=jobs[selected].in_there)
			    { changes_txt+='stage in there,'; }

  			    if(window.document.forms[0].stageouthere.value!=jobs[selected].out_here)
			    { changes_txt+='stage out here,'; }

  			    if(window.document.forms[0].stageoutthere.value!=jobs[selected].out_there)
			    { changes_txt+='stage out there,'; }

			    if(changes_txt!='')
			    {
			      var question_txt='The following changes have been made to a previously'; 
			      question_txt+='submitted job: '+changes_txt; 
			      answer=confirm(question_txt);

			      if(answer)
			      { 
			        // alert('selected='+selected); 
			        window.document.forms[0].orders.value='submitjob';
			        window.document.forms[0].jobname.value=
			           window.document.forms[0].jobselect.options[selected].value;
			        window.document.forms[0].submit(); 
  			      }
			    }
			    else
		            { 
			      window.document.forms[0].jobname.value=
			           window.document.forms[0].jobselect.options[selected].value;
			      window.document.forms[0].orders.value='submitjob';
			      window.document.forms[0].submit(); 
			    }
			  }
                        }
			   ";
   }
   else
   {
     $javascript_str.="
                       function checkSubmit()
                       {
                        window.document.forms[0].jobname.value=
                             window.document.forms[0].jobselect.value;
                        window.document.forms[0].orders.value='submitjob';
                        window.document.forms[0].submit(); 
                       }
		     ";
   }

     $javascript_str.="
			function doNew()
			{
			  window.document.forms[0].orders.value='newjob';
			  window.document.forms[0].submit();
			}
                    ";
  $javascript_str.="\n\n";

?>

<html>
  <head>
    <title>PBSWeb Script Submission</title>
    <script language="JavaScript">
    <!-- Hide script
    <?php
       echo $javascript_str;
       echo "// hostname is $host; programname is $program";
    ?>
    // End script hiding -->
    </script>

  </head>
  <body bgcolor="white">
    <h1>
    <img src="img/littlepbsguy.jpg" border="0" height="102" width="92" alt="PBS Logo">PBSWeb Script Submission
    </h1>
<?php
  /* Put standard navigation menu */
  include("navbar.php");
?>
    <hr>
    <?php
         if('submitjob'==$orders)
	 {
	   echo $submitted_job_str;
	 }
	 else
	 {
    ?>
    <form method="POST" action="submitscript.php" name="form1">
    <input type="hidden" name="jobname" value="">
    <input type="hidden" name="orders" value="">

    <?php
         echo "\n<input type='hidden' name='host' value='$host'>";
         echo "\n<input type='hidden' name='program' value='$program'>";
    ?>

    <table border="5" cellpadding="6">
      <tr>
         <td>
               <?php
	            if('newjob'==$orders)
		    { echo "<b>Job name:</b>"; } 
		    else
		    { echo "<b>Job names:</b><br>"; } 
               ?>
	       <table>
	       <tr>
                  <td>
                     <?php
			// Debug
			// $tcount = count($jobnames_list);
			// echo "<pre>$tcount</pre>";

		         if('newjob'==$orders)
			 {
		          echo "\n\t\t<input type='text' name='jobselect' size='30'>";
			 }
			 else
			 {
		          echo "\n\t\t<select name='jobselect' size='6' cols='30' onChange='javascript:populateProperties()'>";

			// Paul
                          foreach ($jobnames_list as $tmp_jobname)
                          {
				echo "\n\t\t\t<option value='$tmp_jobname'>$tmp_jobname";
			  }
                          echo "\n\t\t</select>";

                          echo "\n\t\t</td>";
                          echo "\n\t\t<td>";
		          echo "\n\t\t<table>";

			// Paul
			    if( count($jobnames_list) != 0 )
		            {
		              echo "\n\t\t<tr><td align='center'>
			                        <input type='button' value='New' onClick='javascript:doNew()'>
				          </td></tr>";
		              echo "\n\t\t<tr><td align='center'>
			                    <input type='button' value='Show all' onClick='javascript:showDeleted()'>
			    	      </td></tr>";
		              echo "\n\t\t</table>";
                              echo "\n\t\t</td>";
			    }
			// Case:  No jobs names yet
			    else
			    {
		              echo "\n\t\t<tr><td align='center'>
			                        <input type='button' value='New (!! click here before entering commands !!)' onClick='javascript:doNew()'>
				          </td></tr>";
		              echo "\n\t\t</table>";
                              echo "\n\t\t</td>";
			    }
                         }
                     ?>
              </tr>
	      </table>
         </td>
         <td>
              <b>Execution Commands:</b><br>
              <textarea name="commands" rows=9 cols=60 wrap="soft"></textarea>
         </td>
      </tr>
      <tr><td>
         <B>Job Options</B><BR>
         <table>
         <tr>
	     <td>Queue to submit job to:</td>
             <td>
             <select name="queue">
             <?php
	       echo "\n<option value=''>Default\n"; 
               # Vick 20010221 allow selecting all available queues 
	       # except when submitting job (this test is redundant, 
	       # we are in the non-submitjob anyway)
	       if('submitjob'!=$orders)
	       {
		 echo "\n<option value='Default'>Default\n";
        	 foreach ($qarray_computed_above as $queue_name) 
		 { echo "\n<option value='$queue_name'>$queue_name"; }
	       }
            ?>
	    </select> 
            </td>
	</tr>
        <tr>
	   <td>Number of processors to use:</td>
           <td>
	       <select name="ncpus">
               <?php
                 # Vick 20010221 allow selecting all available queues 
	         # except when submitting job (this test is redundant, 
	         # we are in the non-submitjob anyway)
	         if('submitjob'!=$orders)
	         {
		   // Chris 20010601: This will change to get the maximum
		   // number of processors from the database.
                    $cpus = 64;
                    for ($i=1;$i<=$cpus;$i++) 
		    {

		      // Chris 20010601: This will change to get the default
		      // number of cpus from the database.
			if(($host=="aurora.nic.ualberta.ca")&&($queue==" borealis")&&($i==8))
		        { echo "<option value='8' selected>8"; }
			else
		        { echo "<option value='$i'>$i"; }
		    }
                 }
	         else
	         { echo "<option value='0'>0"; }
              ?>
	      </select>
	   </td>
       </tr>
       <tr>
          <td>Maximum time (HH:MM:SS)</td>
          <td><input type="text" name="maxtime" value="01:00:00" size=8></td>
          <td align="left">(00:00:00 = no time limit)</td>
       </tr>
       <tr>
          <td>Merge STDERR to STDOUT?</td>
	  <td> <input type="checkbox" name="join" value="1"> </td>
       </tr>
       <tr>
           <td>Send message when job:</td>
           <td>
              <input type='checkbox' name='mailabort' value='1'>Aborts
              <input type='checkbox' name='mailend'   value='1'>Ends
              <input type='checkbox' name='mailbegin' value='1'>Starts
           </td>
       </tr>
       <tr>
           <td>Address to send messages to:</td>
           <td>
	       <?php
	          if('newjob'==$orders)
		  { echo "<input type='text' name='address' value='$dbaddress' size='20'>"; }
		  else
		  { echo "<input type='text' name='address' size='20'>"; }
               ?>
           </td>
       </tr>
       </table>
    </td>
    <td>
    <b>File Staging <em>(data files only; executable automatically staged)</em></b>
    <table>
           <tr><td><em>Stagein</em></td></tr>
           <tr> 
	       <td>From here:</td>
	       <td><input type="text" name="stageinhere" size=25></td>
	   </tr>
           <tr> 
	       <td>To there:</td>
	       <td><input type="text" name="stageinthere" size=25></td>
	   </tr>
           <tr><td><em>Stageout</em></td></tr>
           <tr> 
	       <td>From here:</td>
	       <td><input type="text" name="stageouthere" size=25></td>
	   </tr>
           <tr> 
	       <td>To there:</td>
	       <td><input type="text" name="stageoutthere" size=25></td>
	   </tr>
           <tr><td>
	       <input type="button" name="stageclear" value="Clear filestaging" onClick="clearFileStaging()">
	   </td></tr>
    </table>
    </td></tr>
    <tr>
        <td> <input type="button" value="Submit Job" onClick="javascript:checkSubmit();">
             <!-- Vick 20010220 temporarily commented out <a href="uploadscript.php">Upload Your Own Scriptfile</a>  -->

        </td>
    </tr>
    <tr><td>
    </td></tr>
    <tr>
        <td> <a href="mainmenu.php">Start Page</a></td> 
        <td> Send questions and comments to <a
	href="mailto:pbsweb@cs.ualberta.ca">pbsweb@cs.ualberta.ca</a>. You can find <a
	href='help.html'> help here </a>.</td>
    <tr>
    </td></tr>
    </form>
    </table>
    <?php
         } # if not submit_job
    ?>
  </body>
</html>
